@@ -9,8 +9,9 @@
 Marshal values of types that make up 'Inline' elements.
 -}
 module Text.Pandoc.Lua.Marshal.Inline
-  ( -- * Single Inline elements
-    peekInline
+  ( typeInline
+    -- * Single Inline elements
+  , peekInline
   , peekInlineFuzzy
   , pushInline
     -- * List of Inlines
@@ -25,9 +26,10 @@ module Text.Pandoc.Lua.Marshal.Inline
   , walkInlinesStraight
   ) where
 
-import Control.Applicative (optional)
+import Control.Applicative ((<|>), optional)
 import Control.Monad.Catch (throwM)
 import Control.Monad ((<$!>))
+import Data.Aeson (encode)
 import Data.Data (showConstr, toConstr)
 import Data.Maybe (fromMaybe)
 import Data.Text (Text)
@@ -76,6 +78,27 @@ pushInlines xs = do
       <#> parameter peekFilter "Filter" "lua_filter" "table of filter functions"
       =#> functionResult pushInlines "Blocks" "modified list"
     rawset (nth 3)
+
+    pushName "clone"
+    pushDocumentedFunction $ lambda
+      ### return
+      <#> parameter peekInlinesFuzzy "Inlines" "self" ""
+      =#> functionResult pushInlines "Inlines" "deep copy"
+    rawset (nth 3)
+
+    pushName "__tostring"
+    pushDocumentedFunction $ lambda
+      ### liftPure show
+      <#> parameter peekInlinesFuzzy "Inlines" "self" ""
+      =#> functionResult pushString "string" "native Haskell representation"
+    rawset (nth 3)
+
+    pushName "__tojson"
+    pushDocumentedFunction $ lambda
+      ### liftPure encode
+      <#> parameter peekInlinesFuzzy "Inlines" "self" ""
+      =#> functionResult pushLazyByteString "string" "JSON representation"
+    rawset (nth 3)
   setmetatable (nth 2)
 {-# INLINABLE pushInlines #-}
 
@@ -93,10 +116,10 @@ peekInlinesFuzzy :: LuaError e
                  => Peeker e [Inline]
 peekInlinesFuzzy idx = liftLua (ltype idx) >>= \case
   TypeString -> B.toList . B.text <$> peekText idx
-  _ -> choice
-       [ peekList peekInlineFuzzy
-       , fmap pure . peekInlineFuzzy
-       ] idx
+  _ ->  peekList peekInlineFuzzy idx
+    <|> (pure <$> peekInlineFuzzy idx)
+    <|> (failPeek =<<
+         typeMismatchMessage "Inline, list of Inlines, or string" idx)
 {-# INLINABLE peekInlinesFuzzy #-}
 
 -- | Inline object type.
@@ -111,6 +134,10 @@ typeInline = deftype "Inline"
       <#> parameter (optional . peekInline) "a" "Inline" ""
       <#> parameter (optional . peekInline) "b" "Inline" ""
       =#> functionResult pushBool "boolean" "whether the two are equal"
+  , operation (CustomOperation "__tojson") $ lambda
+    ### liftPure encode
+    <#> udparam typeInline "self" ""
+    =#> functionResult pushLazyByteString "string" "JSON representation"
   ]
   [ possibleProperty "attr" "element attributes"
       (pushAttr, \case
