@@ -120,6 +120,54 @@ return {
           Div('word', {'my-other-div', {'example'}}),
           div
         )
+      end),
+      test('accessing the content does not change the value', function ()
+        local div = Div {}
+        assert.are_equal(div, Div{})
+        x = div.content
+        assert.are_equal(div, Div{})
+      end)
+    },
+    group 'Figure' {
+      test('access content via property `content`', function ()
+        local elem = Figure{BlockQuote{Plain 'word'}}
+        assert.are_same(elem.content, {BlockQuote{'word'}})
+        assert.are_equal(type(elem.content), 'table')
+
+        elem.content = {
+          Para{Str 'one'},
+          Para{Str 'two'}
+        }
+        assert.are_equal(
+          Figure{
+            Para 'one',
+            Para 'two'
+          },
+          elem
+        )
+      end),
+      test('access caption via property `caption`', function ()
+        local figure = Figure('word', {short='short', long='caption'})
+        assert.are_equal(figure.caption.long, Blocks 'caption')
+        assert.are_equal(figure.caption.short, Inlines 'short')
+        assert.are_equal(type(figure.caption), 'table')
+
+        figure.caption = {long = 'One day I was...', short = 'My day'}
+        assert.are_equal(
+          Figure('word', {long = 'One day I was...', short = 'My day'}),
+          figure
+        )
+      end),
+      test('access Attr via property `attr`', function ()
+        local figure = Figure('word', {long='caption'}, {'my-fig', {'sample'}})
+        assert.are_equal(figure.attr, Attr{'my-fig', {'sample'}})
+        assert.are_equal(type(figure.attr), 'userdata')
+
+        figure.attr = Attr{'my-other-figure', {'example'}}
+        assert.are_equal(
+          Figure('word', {long='caption'}, {'my-other-figure', {'example'}}),
+          figure
+        )
       end)
     },
     group 'Header' {
@@ -177,11 +225,6 @@ return {
         )
       end)
     },
-    group 'Null' {
-      test('Can be constructed', function ()
-        assert.are_equal(Null().t, 'Null')
-      end)
-    },
     group 'OrderedList' {
       test('access items via property `content`', function ()
         local para = Plain 'one'
@@ -319,7 +362,23 @@ return {
           Table({long = {}}, {}, TableHead(), {}, new_foot),
           tbl
         )
-      end)
+      end),
+      test('caption field accepts list of blocks', function ()
+        local caption = {long = {Plain 'cap'}}
+        local tbl = Table(caption, {}, TableHead(), {}, TableFoot())
+        assert.are_same(tbl.caption, {long = {Plain 'cap'}})
+
+        tbl.caption = {Plain 'extended'}
+
+        local new_caption = {
+          short = nil,
+          long = {Plain 'extended'}
+        }
+        assert.are_equal(
+          Table(new_caption, {}, TableHead(), {}, TableFoot()),
+          tbl
+        )
+      end),
     },
   },
   group "Blocks" {
@@ -349,6 +408,39 @@ return {
           {'Header', 'CodeBlock'}
         )
       end),
+      test('gives sensible error message', function ()
+        assert.error_matches(
+          function() Blocks(nil) end,
+          'Block, list of Blocks, or compatible element expected'
+        )
+      end)
+    },
+    group 'clone' {
+      test('function exists', function ()
+        assert.are_equal(type(Blocks({}).clone), 'function')
+      end),
+      test('clones the list', function ()
+        local blks = Blocks{Para('One'), CodeBlock 'two'}
+        assert.are_same(blks, blks:clone())
+      end),
+      test('deep-clones the list', function ()
+        local blks = Blocks{Para('one'), CodeBlock 'two'}
+        local copy = blks:clone()
+        copy[1].content[1].text = 'heh'
+        assert.are_same(Blocks{Para('heh'), CodeBlock 'two'}, copy)
+        assert.are_same(Blocks{Para('one'), CodeBlock 'two'}, blks)
+      end)
+    },
+    group 'tostring' {
+      test('works on an empty list', function ()
+        assert.are_equal(tostring(Blocks{}), '[]')
+      end),
+      test('para singleton', function ()
+        assert.are_equal(
+          tostring(Blocks{Para 'Hallo'}),
+          '[Para [Str "Hallo"]]'
+        )
+      end),
     },
     group 'walk' {
       test('modifies Inline subelements', function ()
